@@ -979,6 +979,9 @@ objSize.simList <- function(x, quick = TRUE, ...) {
     try(rm(list = c("Par", "mod"), envir = objTmp$.mods[[mo]]))
   }
 
+  # .wrap the metadata ... i.e,. @depends
+  objTmp <- .wrapOrUnwrapSimListAts(objTmp, .wrap)
+
   # Need to wrap the objects in e.g., .mods for e.g., mod objects that might be e.g., SpatVector
   objTmp$.mods <- .wrap(objTmp$.mods, cachePath = cachePath, drv = drv, conn = conn, verbose = verbose)
   # Deal with the potentially large things -- convert to list -- not a copy
@@ -992,6 +995,73 @@ objSize.simList <- function(x, quick = TRUE, ...) {
   objTmp
 }
 
+
+.wrapOrUnwrapSimListAts <- function(obj, wrapOrUnwrap = .wrap) {
+  sns <- slotNames(obj)
+  sns <- sns[!startsWith(sns, ".")]
+  for (sn in sns) {
+    slot(obj, sn) <- wrapOrUnwrap(slot(obj, sn))
+  }
+  obj
+}
+
+
+
+#' @export
+#' @inheritParams reproducible::.unwrap
+#' @importFrom reproducible .unwrap
+#' @rdname dealWithClass
+.wrap..simDeps <- function(obj, ...) {
+  wrapAndUnwrapAtDepends(obj, .wrap)
+}
+
+#' @export
+#' @inheritParams reproducible::.unwrap
+#' @importFrom reproducible .unwrap
+#' @rdname dealWithClass
+.unwrap..simDeps <- function(obj, ...) {
+  wrapAndUnwrapAtDepends(obj, .unwrap)
+}
+
+wrapAndUnwrapAtDepends <- function(obj, wrapOrUnwrap = .wrap) {
+  sn <- "dependencies"
+  deps <- slot(obj, sn)
+  fn <- wrapOrUnwrap
+  for (mod in names(deps)) {
+    deps[[mod]] <- fn(deps[[mod]])
+  }
+  slot(obj, sn) <- deps
+  obj
+}
+
+
+
+#' @export
+#' @inheritParams reproducible::.unwrap
+#' @importFrom reproducible .unwrap
+#' @rdname dealWithClass
+.wrap..moduleDeps <- function(obj, ...) {
+  wrapAndUnwrapDotMmoduleDeps(obj, .wrap)
+}
+
+#' @export
+#' @inheritParams reproducible::.unwrap
+#' @importFrom reproducible .unwrap
+#' @rdname dealWithClass
+.unwrap..moduleDeps <- function(obj, ...) {
+  wrapAndUnwrapDotMmoduleDeps(obj, .unwrap)
+}
+
+
+wrapAndUnwrapDotMmoduleDeps <- function(deps, wrapOrUnwrap = .wrap) {
+  snsInner <- slotNames(deps)
+  fn <- wrapOrUnwrap
+  for (snInner in snsInner) {
+    slot(deps, snInner) <- fn(slot(deps, snInner))
+  }
+  deps
+}
+
 #' @export
 #' @inheritParams reproducible::.unwrap
 #' @importFrom reproducible .unwrap
@@ -1006,6 +1076,10 @@ objSize.simList <- function(x, quick = TRUE, ...) {
   outList <- .unwrap(objList, cachePath = cachePath, cacheId = cacheId,
                      drv = drv, conn = conn, ...)
   list2env(outList, envir = envir(obj))
+
+  # .unwrap the metadata ... i.e,. @depends
+  obj <- .wrapOrUnwrapSimListAts(obj, wrapOrUnwrap = .unwrap)
+
   obj
 }
 
