@@ -107,3 +107,24 @@ test_that("paths file does not work correctly", {
   terraPath(mySim) <- tmpdir
   expect_equal(terraPath(mySim), tmpdir)
 })
+
+test_that("absolutizePaths can handle multiple paths", {
+  test_paths <- list(
+    cachePath = "/mnt/scratch/achubaty/BC_HRV/cache",
+    inputPath = "mnt/projects/HRV/BC_HRV/inputs",
+    modulePath = c("/home/achubaty/GitHub/BC_HRV/modules",
+                   "/home/achubaty/GitHub/BC_HRV/modules/scfm/modules"),
+    outputPath = "/mnt/projects/HRV/BC_HRV/outputs/NRD_Quesnel_scfm_hrv_FRT_res125/rep01",
+    rasterPath = "/mnt/scratch/achubaty/BC_HRV/raster",
+    scratchPath = "/mnt/scratch/achubaty/BC_HRV",
+    terraPath = "/mnt/scratch/achubaty/BC_HRV/terra"
+  )
+
+  expect_no_error({
+    out <- absolutizePaths(paths = test_paths,
+                           projectPath = "/home/achubaty/GitHub/BC_HRV",
+                           tempdir = "/mnt/scratch/achubaty/tmp/RtmpJ0cOm1")
+  })
+
+  expect_equivalent(sapply(out, length), c(1, 1, 2, 1, 1, 1, 1))
+})
