@@ -6,7 +6,7 @@ test_that("simulation runs with simInit and spades with set.seed; events arg", {
 
   times <- list(start = 0.0, end = 1, timeunit = "year")
   params <- list(
-    .globals = list(burnStats = "npixelsburned", stackName = "landscape"),
+  #   .globals = list(burnStats = "npixelsburned", stackName = "landscape"),
     randomLandscapes = list(.plotInitialTime = NA, .plotInterval = NA, .seed = list("init" = 321)),
     caribouMovement = list(.plotInitialTime = NA, .plotInterval = NA, torus = TRUE),
     fireSpread = list(.plotInitialTime = NA, .plotInterval = NA)
@@ -544,7 +544,7 @@ test_that("conflicting function types", {
                                            "Running .inputObjects|",
                                            "Setting:|Paths set to:|",
                                            "Using setDTthreads|",
-                                           m, ": using dataPath|", "Elpsed")))))
+                                           m, ": using dataPath|", "Elapsed")))))
 
   # assign to sim for functions like scheduleEvent
   lineWithScheduleEvent <- grep(xxx, pattern = "scheduleEvent")[1]
@@ -936,6 +936,7 @@ test_that("simInitAndSpades", {
     spades(debug = FALSE)
 
   expect_true(all.equal(mySim, mySim2))
+
 })
 
 test_that("scheduleEvent with invalid values for eventTime", {
